#!/usr/bin/perl
#
# fbx-playlist.pl
# Copyright (C) 2005 Freebox S.A.
# written by Clement Vasseur <cvasseur@freebox.fr>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

use strict;
use warnings;
use Cwd 'abs_path';

my @opt_jpg = (
  "sout=#transcode:std",
  "sout-transcode-width=720",
  "sout-transcode-height=576",
  "sout-transcode-vb=9000",
  "sout-transcode-vcodec=mp2v",
  "sout-transcode-vt=1000000",
  "sout-transcode-vfilter=deinterlace",
  "sout-deinterlace-mode=blend",
  "sout-ffmpeg-keyint=1"
);

my @opt_dvd = (
  "sout=#transcode:std",
  "sout-transcode-ab=384",
  "sout-transcode-acodec=mpga",
  "sout-transcode-channels=2",
  "file-caching=1000"
);

my @opt_avi = (
  "sout=#transcode:std",
  "sout-transcode-ab=384",
  "sout-transcode-acodec=mpga",
  "sout-transcode-channels=2",
  "sout-transcode-vb=9000",
  "sout-transcode-vcodec=mp2v",
  "sout-transcode-vt=1000000",
  "file-caching=1000"
);

if (@ARGV == 0 or $ARGV[0] eq '-h') {
  print "usage: $0 file1.mpg file2.avi ...\n";
  exit 1;
}

print "#EXTM3U\n";

foreach my $filename (@ARGV) {
  my $name;
  my $ext;

  $filename = abs_path($filename);

  ($name, $ext) = $filename =~ m/([^\.\/]+)\.([^\.\/]+)$/;
 
  print "#EXTINF:0,$name\n";

  if ($ext =~ m/^vob$/i) {
    print "#EXTVLCOPT:$_\n" foreach @opt_dvd;
    print "$filename\n";

  } elsif ($ext =~ m/^(avi|ogg|mp3|mkv|mp4|mov|aac|au|aif|aiff|mjpeg|wmv|wma|wav|asf)$/i) {
    print "#EXTVLCOPT:$_\n" foreach @opt_avi;
    print "$filename\n";

  } elsif ($ext =~ m/^(jpg|jpeg|png|tiff|gif)$/i) {
    print "#EXTVLCOPT:$_\n" foreach @opt_jpg;
    print "#EXTVLCOPT:fake-file=$filename\n";
    print "fake:\n";

  } elsif ($name =~ m/^\/dev\//i) {
    print "#EXTVLCOPT:$_\n" foreach @opt_dvd;
    print "dvdsimple:$filename\n";

  } elsif ($name =~ m/^http:\/\//i) {
    print "#EXTVLCOPT:$_\n" foreach @opt_avi;
    print "$filename\n";

  } else {
    print "$filename\n";
  }
}
